@@ -21,7 +21,7 @@ import pydot
 import unittest
 
 
-DOT_BINARY_PATH = 'dot'
+TEST_PROGRAM = 'dot'
 TESTS_DIR_1 = 'my_tests'
 TESTS_DIR_2 = 'graphs'
 
@@ -72,9 +72,8 @@ class TestGraphAPI(unittest.TestCase):
         g.add_node(node)
         node.set('label', 'mine')
         s = g.to_string()
-        s_0 = 'digraph G {\nlegend [label=mine, shape=box];\n}\n'
-        s_1 = 'digraph G {\nlegend [shape=box, label=mine];\n}\n'
-        assert s == s_0 or s == s_1, (s, s_0)
+        expected = 'digraph G {\nlegend [label=mine, shape=box];\n}\n'
+        assert s == expected
 
     def test_attribute_with_implicit_value(self):
 
@@ -141,19 +140,16 @@ class TestGraphAPI(unittest.TestCase):
 
 
     def test_graph_with_shapefiles(self):
-
-        shapefile_dir = os.path.join(test_dir,
-                                     'from-past-to-future')
+        shapefile_dir = os.path.join(test_dir, 'from-past-to-future')
         # image files are omitted from sdist
         if not os.path.isdir(shapefile_dir):
             warnings.warn('Skipping tests that involve images, '
                           'they can be found in the `git` repository.')
             return
-        dot_file = os.path.join(shapefile_dir,
-                                'from-past-to-future.dot')
+        dot_file = os.path.join(shapefile_dir, 'from-past-to-future.dot')
 
 
-        pngs = dot_files = [
+        pngs = [
             os.path.join(shapefile_dir, fname) for
             fname in os.listdir(shapefile_dir)
             if fname.endswith('.png')]
@@ -185,20 +181,22 @@ class TestGraphAPI(unittest.TestCase):
 
     def _render_with_graphviz(self, filename, encoding):
         with io.open(filename, 'rt', encoding=encoding) as stdin:
-            p = subprocess.Popen(
-                [DOT_BINARY_PATH, '-Tjpe'],
-                cwd=os.path.dirname(filename),
+            stdout_data, stderr_data, process = pydot.call_graphviz(
+                program=TEST_PROGRAM,
+                arguments=['-Tjpe', ],
+                working_dir=os.path.dirname(filename),
                 stdin=stdin,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE)
-        stdout_data, stderr_data = p.communicate()
+            )
+
+        assert process.returncode == 0, stderr_data
+
         return sha256(stdout_data).hexdigest()
 
     def _render_with_pydot(self, filename, encoding):
         c = pydot.graph_from_dot_file(filename, encoding=encoding)
         sha = ''
         for g in c:
-            jpe_data = g.create(format='jpe', encoding=encoding)
+            jpe_data = g.create(prog=TEST_PROGRAM, format='jpe', encoding=encoding)
             sha += sha256(jpe_data).hexdigest()
         return sha
 
@@ -228,8 +226,8 @@ class TestGraphAPI(unittest.TestCase):
             os.sys.stdout.write('#')
             os.sys.stdout.flush()
             pydot_sha = self._render_with_pydot(fpath, encoding)
-            pydot_sha = self._render_with_graphviz(fpath, encoding)
-            assert pydot_sha == pydot_sha, (pydot_sha, pydot_sha)
+            graphviz_sha = self._render_with_graphviz(fpath, encoding)
+            assert pydot_sha == graphviz_sha, (pydot_sha, graphviz_sha)
 
     def test_numeric_node_id(self):
 
@@ -295,15 +293,15 @@ class TestGraphAPI(unittest.TestCase):
 
         self._reset_graphs()
 
-        names = set([ 'node_%05d' % i for i in range(10**3) ])
+        names = { 'node_%05d' % i for i in range(10**3) }
 
         for name in names:
 
             self.graph_directed.add_node( pydot.Node(name, label=name) )
 
         self.assertEqual(
-            set([n.get_name()
-                 for n in self.graph_directed.get_nodes()]), names)
+            {n.get_name()
+                 for n in self.graph_directed.get_nodes()}, names)
 
 
     def test_executable_not_found_exception(self):
@@ -375,7 +373,4 @@ if __name__ == '__main__':
     check_path()
     test_dir = os.path.dirname(sys.argv[0])
     print('The tests are using `pydot` from:  {pd}'.format(pd=pydot))
-    if sys.version_info >= (2, 7):
-        unittest.main(verbosity=2)
-    else:
-        unittest.main()
+    unittest.main(verbosity=2)
